.. _cucm-configuration-voss-automate:

CUCM Configuration
---------------------


.. _19.2.1|EKB-2692:

Overview
........

Cisco Unified Communications Manager (CUCM) devices provide the core call processing
capabilities for HCS, and are a critical part of the VOSS Automate provisioning
workflows. You must configure the CUCM devices before you complete the
dial plan (if applicable), user, subscriber, line, and phone configuration.

CUCM devices can be dedicated to a specific customer, or they can be shared
between multiple customers. CUCM devices must then be assigned to one or
more Network Devices Lists (NDLs), and the NDL is then assigned to one or more
sites. The NDL is used to select which CUCM is used for configuration based
on the site selected in the hierarchy context.



.. rubric:: Related Topics

* 
  .. raw:: latex

     Flow Through Provisioning in the Core Feature Guide

  .. raw:: html
  
     <a href="flow-through-provisioning.html">Flow Through Provisioning</a> 



Shared versus Dedicated
.......................

To share the CUCM across multiple customers, add the CUCM at the
Provider or Reseller level. To dedicate the CUCM to a single customer, add
the CUCM at the Customer level.

When setting up CUCM as a dedicated instance, you can opt to set up CUCM after you create the customer.


Servers within a CUCM Cluster
...............................

Within a CUCM cluster, you can configure the following nodes:

* Cisco Unified Communications Manager Publisher
* Cisco Unified Communications Manager Subscriber
* IM and Presence Service Publisher
* IM and Presence Service Subscriber

Configure a CUCM Publisher node before configuring any other type node.

Configure an IM and Presence Service Publisher node before configuring an IM and
Presence Service Subscriber node.


Sync with VOSS Automate
........................


Configuring a CUCM device on VOSS Automate creates a scheduled data sync to
import model data from the device into VOSS Automate. The scheduled data sync ensures
that the VOSS Automate cache maintains the most current view of the configured device.
Any changes to the configuration occurring on the device, including additions,
deletions, or modifications, will be reflected in VOSS Automate after the next data
sync.

.. note::

   * There is no immediate data sync upon Update or Modification.
   * The scheduled data sync fails if the CUCM administrator account credential
     has expired. Expiration of the administrator account credential can cause
     failures in Subscriber Management activities as well.
   * Some license-related models will now be excluded from CUCM imports by default:

     * ``device/cucm/LicensedUser``
     * ``device/cucm/LicensingResourceUsage``
     * ``device/cucm/HcsLicense``

The recurring sync is scheduled to occur every 14 days, but is disabled by default.
You can enable the sync and modify the schedule from **Apps Management > CUCM > Schedules**.
When determining the appropriate schedule setting, the frequency of the sync must be
weighed against the additional processing and network activity associated with
the data sync. You can also manually run the data sync at any time from
**Apps Management > Advanced > Perform Publisher Actions**, or from
**Administration Tools > Data Sync**.

.. important::

   Allow the initial data sync to complete before doing more configuration on
   VOSS Automate that requires information from CUCM.

.. note:: 

   On Provider deployments, references to HCM-F and Shared Data Repository (SDR) are only relevant if
   installed.

When you set up an IM and Presence Service server, VOSS Automate does not communicate
directly with the IM and Presence Service server. The information provided is
pushed to HCM-F and Service Assurance (if installed) for monitoring purposes.

The performance of a data sync can be improved by controlling the types of data
that are synced. See :ref:`controlling-a-data-sync-with-a-model-type-list` for
more information.

For details on Change Notification Sync in VOSS Automate and on switching 
between Full Sync and Change Notification Sync, refer to the 
topic on the Change Notification Feature (CNF) following :ref:`voss-cnf-overview`.

Field Mappings in CUCM
........................

When setting up a CUCM device with LDAP integration, you can map CUCM 
user data to VOSS Automate user data for any field, based on the Field Mappings in
the CUCM server. These mappings are configured at the LDAP Directory in
CUCM. The mapped user data, for example location data, can later be used in
a filter used to move users to sites.

On the Field Mappings tab, you can modify the mappings except for hard-coded
mappings. Hard-coded mappings appear in gray and are read-only.

.. note::

   The field name entered in the mapping on VOSS Automate must exactly match the
   field name entered in the mapping in the CUCM in the Custom User Field
   Name field. If the field names do not match, the field is skipped during the
   sync.


.. rubric:: Related Topics

* 
  .. raw:: latex

     User Field Mapping in the Core Feature Guide

  .. raw:: html
  
     <a href="concepts-user-field-mapping.html">User Field Mapping</a> 